@@ -1,8 +1,9 @@
 var _pro_s_h_a_d_e__data_8cpp =
 [
     [ "GEMMI_WRITE_IMPLEMENTATION", "_pro_s_h_a_d_e__data_8cpp.html#aafad822f69e0d17ceb44d769bb05a7b2", null ],
+    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__data_8cpp.html#a262d9e21cd6b81b8bda35ec22eb363dd", null ],
     [ "axesToGroupTypeSanityCheck", "_pro_s_h_a_d_e__data_8cpp.html#a188746757d4fe33cc7bca307aa367bc7", null ],
     [ "checkElementAlreadyExists", "_pro_s_h_a_d_e__data_8cpp.html#ae56351defa0ee4f5777b61e58150aba4", null ],
     [ "checkElementsFormGroup", "_pro_s_h_a_d_e__data_8cpp.html#aa430bcd7dc43633680907360656b7799", null ],
-    [ "prependIdentity", "_pro_s_h_a_d_e__data_8cpp.html#aef1bf7fc5ea3603f3a1f619e23e9d981", null ]
+    [ "sortProSHADESymmetryByFSC", "_pro_s_h_a_d_e__data_8cpp.html#ae2a2bd26e2e081130593c7783c54f293", null ]
 ];
\ No newline at end of file
