@@ -12,8 +12,6 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "centreMapOnCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a80ff45ef40549fb6a1d80b70865fc807", null ],
     [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2b60ba4e2dd8ef4918b6f0ea5316a009", null ],
     [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a60643383ab239888adeee6e757876c80", null ],
-    [ "computeOptimalTranslation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a68ac89c84a5e67582d050218566d9a44", null ],
-    [ "computePdbRotationCentre", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa48fc72e389e663248d27eedbbf32314", null ],
     [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad39f33c52f6d4f0db8e0d63ed0c9a2f3", null ],
     [ "computeRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac7cb89ed871668c57a3b5dc953c20482", null ],
     [ "computeRRPMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6db2dcf87a6f763909ab08201e8de550", null ],
@@ -23,7 +21,6 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "createNewMapFromBounds", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3349a7f6ffecc3ffd4e09192eb919248", null ],
     [ "deepCopyMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac3fbad5b8628112ace798950e6068bd4", null ],
     [ "detectSymmetryFromAngleAxisSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abcf770f9177a4d2f1a94a3adb20bf790", null ],
-    [ "detectSymmetryInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afac05cfadc141435c4fc4a568ecffe29", null ],
     [ "figureIndexStartStop", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a476092aa08dff20d64a895e7b2227b2e", null ],
     [ "findMapCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac07955296611dd411cf5ed87ced90571", null ],
     [ "findRequestedCSymmetryFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2714fcb2c08b224ccf09d64322bd2ab2", null ],
@@ -31,7 +28,7 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae2f2469c7d252c5e87d7bf9976b9b796", null ],
     [ "getAnySphereRadius", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23620b34a604aca7db4d8b21f6d2d09a", null ],
     [ "getBestRotationMapPeaksEulerAngles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a129f0b665c31fe2d6c7a03f1ba9997de", null ],
-    [ "getBestTranslationMapPeaksAngstrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7955b0afcc99b569aba1023210e23e81", null ],
+    [ "getBestTranslationMapPeaksAngstrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a53412a6bef001a7be8fd98ceaa8a8648", null ],
     [ "getComparisonBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6cc2b8e179a137adda234e0ba0f9d27b", null ],
     [ "getCyclicSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a421d8cf46b6671857d0054cf0defe17f", null ],
     [ "getCyclicSymmetriesListFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afa3b1a8ef870a606035102b5dcf1ce44", null ],
@@ -99,15 +96,17 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "normaliseMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a255bdb77824ce0fddc2454d5823219e1", null ],
     [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51b1eb3cb274c1c68e85cf3cca0c25b7", null ],
     [ "processInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afcb4202e9ffea1b99c59f73faf06d899", null ],
-    [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a07fb6e354dcd90dc70f8b4fa8bba0c33", null ],
+    [ "readInGemmi", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af8dcc353f075b824d2f3479f487c8bd0", null ],
+    [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aae85fef5742e6c6c9ef7bda2ff0f7d23", null ],
     [ "readInPDB", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abd1c1b3588308f775da5c8aeba3f3e78", null ],
-    [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a59f2f2ce1bfdb90432c5a29600fdd9e6", null ],
+    [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a341ab1de3f949e1e4688110ed641ae13", null ],
+    [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aab12fb2b416250b81dd69d2e86313b59", null ],
     [ "removePhaseInormation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5919acc2f26efcf373db47ed96eadc38", null ],
     [ "reportOverlayResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a43e3cad6f93a32f92194f76f0ec76a32", null ],
     [ "reportSymmetryResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abea2d62360b17cddca155816d3e485e8", null ],
     [ "reSampleMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab573ea90a16991a06a77c5343328b060", null ],
-    [ "rotateMapRealSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7c7b69293bb883a84cde8031bb217f0a", null ],
-    [ "rotateMapRealSpaceInPlace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8c4f14e31f4ad0f08d4558b732ef4b8c", null ],
+    [ "rotateMapRealSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a22caf254dfc11e52890f79a161493e6e", null ],
+    [ "rotateMapRealSpaceInPlace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac626ea4513155170cff98fd18e6f3b09", null ],
     [ "rotateMapReciprocalSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa12ba3d9d61e240ec2d91d924e6cb0d3", null ],
     [ "saveDetectedSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0b0608e80f20087b24cc9498767f0894", null ],
     [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a262b3b0e1129d4d3a5830a8982395f01", null ],
@@ -122,10 +121,11 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "shellBandExists", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ada8e6f27f49afc3a0ee17758ce9e7594", null ],
     [ "so3CoeffsArrayIndex", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9f6ba75b25e201466929bfd4df75688d", null ],
     [ "translateMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7170576d4823143e7dd270e0f202d0b4", null ],
+    [ "writeGemmi", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a291d70d6d298ce4094b625f588c83b1c", null ],
     [ "writeMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a81e6aab30488052e6bdd9b339e8124d8", null ],
     [ "writeMask", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aac87b1a87f32a742ea2b41014dac5f7b", null ],
     [ "writeOutOverlayFiles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6160812636f73e33c1c46a754b68a610", null ],
-    [ "writePdb", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0322fb97dcd3c0495f98963210f36c27", null ],
+    [ "writePdb", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a36f99ea1e23f754d65f3612052ce5c42", null ],
     [ "zeroPaddToDims", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0cdec5190d4b2ae60350f0f6db751d4b", null ],
     [ "aAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa75beee618649d6fd9dc850a5a66a551", null ],
     [ "bAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9dbcec9f32eb76625d7aa59d8c2701d9", null ],
