@@ -2,6 +2,6 @@ var dir_5c0d64f70903e893b1efe571a4b8de29 =
 [
     [ "pyProSHADE.cpp", "py_pro_s_h_a_d_e_8cpp.html", "py_pro_s_h_a_d_e_8cpp" ],
     [ "pyProSHADE_bindings.cpp", "py_pro_s_h_a_d_e__bindings_8cpp.html", "py_pro_s_h_a_d_e__bindings_8cpp" ],
-    [ "pyProSHADE_data.cpp", "py_pro_s_h_a_d_e__data_8cpp_source.html", null ],
-    [ "pyProSHADE_distances.cpp", "py_pro_s_h_a_d_e__distances_8cpp_source.html", null ]
+    [ "pyProSHADE_data.cpp", "py_pro_s_h_a_d_e__data_8cpp.html", "py_pro_s_h_a_d_e__data_8cpp" ],
+    [ "pyProSHADE_distances.cpp", "py_pro_s_h_a_d_e__distances_8cpp.html", "py_pro_s_h_a_d_e__distances_8cpp" ]
 ];
\ No newline at end of file
