@@ -46,18 +46,23 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__io_8cpp.html":[3,0,0,1,8],
 "_pro_s_h_a_d_e__io_8cpp_source.html":[3,0,0,1,8],
 "_pro_s_h_a_d_e__io_8hpp.html":[3,0,0,1,9],
-"_pro_s_h_a_d_e__io_8hpp.html#a2e438f3d348e3e065f798031d5a33d09":[3,0,0,1,9,7],
-"_pro_s_h_a_d_e__io_8hpp.html#a63ae2cc7f413d224e5d651ed579e9afb":[3,0,0,1,9,1],
-"_pro_s_h_a_d_e__io_8hpp.html#a6457a6070e82b0955205ed0a95ea3040":[3,0,0,1,9,5],
+"_pro_s_h_a_d_e__io_8hpp.html#a2047cb9106e44b8de3174e34b9578f80":[3,0,0,1,9,3],
+"_pro_s_h_a_d_e__io_8hpp.html#a2e438f3d348e3e065f798031d5a33d09":[3,0,0,1,9,11],
+"_pro_s_h_a_d_e__io_8hpp.html#a354a3899d17c6c5d4bad042dc00f4554":[3,0,0,1,9,2],
+"_pro_s_h_a_d_e__io_8hpp.html#a63ae2cc7f413d224e5d651ed579e9afb":[3,0,0,1,9,5],
+"_pro_s_h_a_d_e__io_8hpp.html#a6457a6070e82b0955205ed0a95ea3040":[3,0,0,1,9,9],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964":[3,0,0,1,9,0],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a02c37da7e1f9b2546ac6f8dab137dc25":[3,0,0,1,9,0,1],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a2ebd61b90723c41f6f03a4a1f5791f1e":[3,0,0,1,9,0,2],
+"_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a5f47bf43e5397417deb998646477b2db":[3,0,0,1,9,0,3],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a931e41099ae6c64ea034b6485a46dfaa":[3,0,0,1,9,0,0],
-"_pro_s_h_a_d_e__io_8hpp.html#a9677e06f0781855b9046aab1b3638831":[3,0,0,1,9,6],
-"_pro_s_h_a_d_e__io_8hpp.html#a9f714e15a7bc56dbe846fda6bb1d9c9e":[3,0,0,1,9,8],
-"_pro_s_h_a_d_e__io_8hpp.html#abc5e6a82b6b44e3666abfc190dc0bc64":[3,0,0,1,9,3],
-"_pro_s_h_a_d_e__io_8hpp.html#ad93f9644c5b132193b4ddd282f50abce":[3,0,0,1,9,4],
-"_pro_s_h_a_d_e__io_8hpp.html#ae496132c658b22a5abb5d7aaca5e1f56":[3,0,0,1,9,2],
+"_pro_s_h_a_d_e__io_8hpp.html#a9677e06f0781855b9046aab1b3638831":[3,0,0,1,9,10],
+"_pro_s_h_a_d_e__io_8hpp.html#a9f714e15a7bc56dbe846fda6bb1d9c9e":[3,0,0,1,9,12],
+"_pro_s_h_a_d_e__io_8hpp.html#aa5e21f1b3dc18338da35951b248e6e38":[3,0,0,1,9,1],
+"_pro_s_h_a_d_e__io_8hpp.html#abc5e6a82b6b44e3666abfc190dc0bc64":[3,0,0,1,9,7],
+"_pro_s_h_a_d_e__io_8hpp.html#ad93f9644c5b132193b4ddd282f50abce":[3,0,0,1,9,8],
+"_pro_s_h_a_d_e__io_8hpp.html#adae94658a4eec4c994e10d267b00fe4c":[3,0,0,1,9,4],
+"_pro_s_h_a_d_e__io_8hpp.html#ae496132c658b22a5abb5d7aaca5e1f56":[3,0,0,1,9,6],
 "_pro_s_h_a_d_e__io_8hpp_source.html":[3,0,0,1,9],
 "_pro_s_h_a_d_e__map_manip_8cpp.html":[3,0,0,1,10],
 "_pro_s_h_a_d_e__map_manip_8cpp_source.html":[3,0,0,1,10],
@@ -192,16 +197,17 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__overlay_8cpp.html":[3,0,0,1,18],
 "_pro_s_h_a_d_e__overlay_8cpp_source.html":[3,0,0,1,18],
 "_pro_s_h_a_d_e__overlay_8hpp.html":[3,0,0,1,19],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a1e7fa43107bc9a9fce49d5954a93c962":[3,0,0,1,19,9],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a1e7fa43107bc9a9fce49d5954a93c962":[3,0,0,1,19,10],
 "_pro_s_h_a_d_e__overlay_8hpp.html#a2a0722746f5c10a2ce4805513cb99fe9":[3,0,0,1,19,1],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a448b6438ea9979e18af75f419f175603":[3,0,0,1,19,5],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a448b6438ea9979e18af75f419f175603":[3,0,0,1,19,6],
 "_pro_s_h_a_d_e__overlay_8hpp.html#a5f5eacf55d707e1d80d3df360fc0fe91":[3,0,0,1,19,0],
 "_pro_s_h_a_d_e__overlay_8hpp.html#a6f02ec45f8f865fe5a7142509f48e41a":[3,0,0,1,19,3],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a75e695f0a6b627e6a670c5e379230f4c":[3,0,0,1,19,4],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a75e695f0a6b627e6a670c5e379230f4c":[3,0,0,1,19,5],
 "_pro_s_h_a_d_e__overlay_8hpp.html#a78c51dc39b75ffb4731c7219b25e290b":[3,0,0,1,19,2],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a92cc970ba9d1e6ab220a0c947ebd5567":[3,0,0,1,19,6],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a96c978e561ed489efc681f640332256a":[3,0,0,1,19,7],
-"_pro_s_h_a_d_e__overlay_8hpp.html#ac173210899aeeae2e207f9acdd7670a7":[3,0,0,1,19,8],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a92cc970ba9d1e6ab220a0c947ebd5567":[3,0,0,1,19,7],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a96c978e561ed489efc681f640332256a":[3,0,0,1,19,8],
+"_pro_s_h_a_d_e__overlay_8hpp.html#ac173210899aeeae2e207f9acdd7670a7":[3,0,0,1,19,9],
+"_pro_s_h_a_d_e__overlay_8hpp.html#aed7eab7c65fccfa0690ef475ae4e2e9e":[3,0,0,1,19,4],
 "_pro_s_h_a_d_e__overlay_8hpp_source.html":[3,0,0,1,19],
 "_pro_s_h_a_d_e__peak_search_8cpp.html":[3,0,0,1,20],
 "_pro_s_h_a_d_e__peak_search_8cpp_source.html":[3,0,0,1,20],
@@ -243,11 +249,5 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__spherical_harmonics_8cpp_source.html":[3,0,0,1,27],
 "_pro_s_h_a_d_e__spherical_harmonics_8hpp.html":[3,0,0,1,28],
 "_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a0d0b0cf8683acd16bc76285b3897b66f":[3,0,0,1,28,6],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a18ff35433a5459c948344bae4bf6284c":[3,0,0,1,28,8],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a38c2dcddc09fd31877eecb17f1d84aa7":[3,0,0,1,28,5],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a3fa7caeb0d21183a39d7cca2d889c437":[3,0,0,1,28,2],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a86bb427280a75c3422b7a7781253be50":[3,0,0,1,28,7],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#aa25c84ea82e4faeb0f41f738a56ca28d":[3,0,0,1,28,1],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#aa3e5098a48755bb2665044472d619029":[3,0,0,1,28,4],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#aac193f1c8e516f31d272b4ba5ea21b26":[3,0,0,1,28,3]
+"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a18ff35433a5459c948344bae4bf6284c":[3,0,0,1,28,8]
 };
