@@ -19,8 +19,8 @@
 #
 #   \author    Michal Tykac
 #   \author    Garib N. Murshudov
-#   \version   0.7.6.0
-#   \date      JUL 2021
+#   \version   0.7.6.1
+#   \date      AUG 2021
 ######################################################
 ######################################################
 
@@ -70,7 +70,6 @@ ps.setAppliedMaskFilename                             ( "" )
 ######################################################
 ### All other (possibly other tasks related) settings
 ps.setExtraSpace                                      ( 0.0 )                        # Extra space in Angs to be added when creating internap map representation. This helps avoid map effects from other cells.
-ps.setSymmetryRotFunPeaks                             ( True )                       # Should the new angle-axis space symmetry detection be used?
 ps.setBicubicInterpolationSearch                      ( True )                       # Should bi-cubic interpolation between peak grid indices be done?
 ps.setMaxSymmetryFold                                 ( 30 )                         # The maximum prime number fold that will be searched for.
 ps.setFSCThreshold                                    ( 0.75 )                       # The threshold for FSC value under which the axis is considered to be likely noise.
