@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.0
-    \date      JUL 2021
+    \version   0.7.6.1
+    \date      AUG 2021
  */
 
 //==================================================== ProSHADE
@@ -37,7 +37,7 @@
 namespace ProSHADE_internal_io
 {
     //================================================ The InputType data type
-    enum InputType                                    { UNKNOWN, PDB, MAP };
+    enum InputType                                    { UNKNOWN, PDB, MAP, GEMMI };
     
     //================================================ Low level file access functions
     InputType figureDataType                          ( std::string fName );
@@ -52,6 +52,16 @@ namespace ProSHADE_internal_io
                                                         proshade_unsign xAxOrder, proshade_unsign yAxOrder, proshade_unsign zAxOrder );
     void readInMapData                                ( gemmi::Ccp4<int8_t> *gemmiMap, proshade_double*& map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds,
                                                         proshade_unsign xAxOrder, proshade_unsign yAxOrder, proshade_unsign zAxOrder );
+    void applyMask                                    ( proshade_double*& map, std::string maskFile, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds,
+                                                        proshade_signed verbose, proshade_double* maskArray = nullptr, proshade_unsign maXInds = 0, proshade_unsign maYInds = 0,
+                                                        proshade_unsign maZInds = 0 );
+    void applyMaskFromArray                           ( proshade_double*& map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds, proshade_double*& mask,
+                                                        proshade_unsign xDimIndsMsk, proshade_unsign yDimIndsMsk, proshade_unsign zDimIndsMsk, proshade_signed verbose );
+    void applyWeights                                 ( proshade_double*& map, std::string weightsFile, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds,
+                                                        proshade_signed verbose, proshade_double* weightsArray = nullptr, proshade_unsign waXInds = 0, proshade_unsign waYInds = 0,
+                                                        proshade_unsign waZInds = 0 );
+    void applyWeightsFromArray                        ( proshade_double*& map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds, proshade_double*& weights,
+                                                        proshade_unsign xDimIndsWgh, proshade_unsign yDimIndsWgh, proshade_unsign zDimIndsWgh, proshade_signed verbose );
     void writeOutMapHeader                            ( gemmi::Ccp4<float> *map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds, proshade_single xDim,
                                                         proshade_single yDim, proshade_single zDim, proshade_single aAng, proshade_single bAng, proshade_single cAng, proshade_signed xFrom,
                                                         proshade_signed yFrom, proshade_signed zFrom, proshade_signed xAxOrigin, proshade_signed yAxOrigin, proshade_signed zAxOrigin,
