@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.0
-    \date      JUL 2021
+    \version   0.7.6.1
+    \date      AUG 2021
  */
 
 //==================================================== Include PyBind11 header
@@ -73,6 +73,8 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def_readwrite                                ( "maskFileName",                         &ProSHADE_settings::maskFileName                        )
         .def_readwrite                                ( "appliedMaskFileName",                  &ProSHADE_settings::appliedMaskFileName                 )
     
+        .def_readwrite                                ( "fourierWeightsFileName",               &ProSHADE_settings::fourierWeightsFileName              )
+    
         .def_readwrite                                ( "reBoxMap",                             &ProSHADE_settings::reBoxMap                            )
         .def_readwrite                                ( "boundsExtraSpace",                     &ProSHADE_settings::boundsExtraSpace                    )
         .def_readwrite                                ( "boundsSimilarityThreshold",            &ProSHADE_settings::boundsSimilarityThreshold           )
@@ -105,7 +107,6 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def_readwrite                                ( "recommendedSymmetryFold",              &ProSHADE_settings::recommendedSymmetryFold             )
         .def_readwrite                                ( "requestedSymmetryType",                &ProSHADE_settings::requestedSymmetryType               )
         .def_readwrite                                ( "requestedSymmetryFold",                &ProSHADE_settings::requestedSymmetryFold               )
-        .def_readwrite                                ( "usePeakSearchInRotationFunctionSpace", &ProSHADE_settings::usePeakSearchInRotationFunctionSpace)
         .def_readwrite                                ( "useBiCubicInterpolationOnPeaks",       &ProSHADE_settings::useBiCubicInterpolationOnPeaks      )
         .def_readwrite                                ( "maxSymmetryFold",                      &ProSHADE_settings::maxSymmetryFold                     )
         .def_readwrite                                ( "fscThreshold",                         &ProSHADE_settings::fscThreshold                        )
@@ -131,7 +132,8 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def                                          ( "setMinimumMaskSize",                   &ProSHADE_settings::setMinimumMaskSize,                     "Sets the requested minimum mask size.",                                                                                    pybind11::arg ( "minMS"         ) )
         .def                                          ( "setMaskSaving",                        &ProSHADE_settings::setMaskSaving,                          "Sets whether the mask should be saved.",                                                                                   pybind11::arg ( "savMsk"        ) )
         .def                                          ( "setMaskFilename",                      &ProSHADE_settings::setMaskFilename,                        "Sets where the mask should be saved.",                                                                                     pybind11::arg ( "mskFln"        ) )
-        .def                                          ( "setAppliedMaskFilename",               &ProSHADE_settings::setAppliedMaskFilename,                 "Sets the filename of the mask data that should be applied to the input map.",                                            pybind11::arg ( "mskFln"        ) )
+        .def                                          ( "setAppliedMaskFilename",               &ProSHADE_settings::setAppliedMaskFilename,                 "Sets the filename of the mask data that should be applied to the input map.",                                             pybind11::arg ( "mskFln"        ) )
+        .def                                          ( "setFourierWeightsFilename",            &ProSHADE_settings::setFourierWeightsFilename,              "Sets the filename of the Fourier weights data that should be applied to the input map.",                                  pybind11::arg ( "fWgFln"        ) )
         .def                                          ( "setMapReboxing",                       &ProSHADE_settings::setMapReboxing,                         "Sets whether re-boxing needs to be done in the appropriate variable.",                                                     pybind11::arg ( "reBx"          ) )
         .def                                          ( "setBoundsSpace",                       &ProSHADE_settings::setBoundsSpace,                         "Sets the requested number of angstroms for extra space in re-boxing in the appropriate variable.",                         pybind11::arg ( "boundsExSp"    ) )
         .def                                          ( "setBoundsThreshold",                   &ProSHADE_settings::setBoundsThreshold,                     "Sets the threshold for number of indices difference acceptable to make index sizes same in the appropriate variable.",     pybind11::arg ( "boundsThres"   ) )
@@ -165,7 +167,6 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def                                          ( "setDetectedSymmetry",                  &ProSHADE_settings::setDetectedSymmetry,                    "Sets the final detected symmetry axes information.",                                                                       pybind11::arg ( "sym"           ) )
         .def                                          ( "setOverlaySaveFile",                   &ProSHADE_settings::setOverlaySaveFile,                     "Sets the filename to which the overlay structure is to be save into.",                                                    pybind11::arg ( "filename"      ) )
         .def                                          ( "setOverlayJsonFile",                   &ProSHADE_settings::setOverlayJsonFile,                     "Sets the filename to which the overlay operations are to be save into.",                                                 pybind11::arg ( "filename"      ) )
-        .def                                          ( "setSymmetryRotFunPeaks",               &ProSHADE_settings::setSymmetryRotFunPeaks,                 "Sets the symmetry detection algorithm type.",                                                                              pybind11::arg ( "rotFunPeaks"   ) )
         .def                                          ( "setBicubicInterpolationSearch",        &ProSHADE_settings::setBicubicInterpolationSearch,          "Sets the bicubic interpolation on peaks.",                                                                                 pybind11::arg ( "bicubPeaks"    ) )
         .def                                          ( "setMaxSymmetryFold",                   &ProSHADE_settings::setMaxSymmetryFold,                     "Sets the maximum symmetry fold (well, the maximum prime symmetry fold).",                                               pybind11::arg ( "maxFold"       ) )
         .def                                          ( "setFSCThreshold",                      &ProSHADE_settings::setFSCThreshold,                        "Sets the minimum FSC threshold for axis to be considered detected.",                                                     pybind11::arg ( "fscThr"        ) )
